@@ -36,10 +36,8 @@ def _validate_wcs(wcs_in, wcs_out, shape_in, shape_out):
         if wcs_in.wcs.spec >= 0 and wcs_out.wcs.spec >= 0:
             if wcs_in.wcs.ctype[wcs_in.wcs.spec] != wcs_out.wcs.ctype[wcs_out.wcs.spec]:
                 raise ValueError(
-                    "The input ({}) and output ({}) spectral "
-                    "coordinate types are not equivalent.".format(
-                        wcs_in.wcs.ctype[wcs_in.wcs.spec], wcs_out.wcs.ctype[wcs_out.wcs.spec]
-                    )
+                    f"The input ({wcs_in.wcs.ctype[wcs_in.wcs.spec]}) and output ({wcs_out.wcs.ctype[wcs_out.wcs.spec]}) spectral "
+                    "coordinate types are not equivalent."
                 )
         elif wcs_in.wcs.spec >= 0:
             raise ValueError("Input WCS has a spectral component but output WCS does not")
@@ -110,7 +108,7 @@ def _reproject_full(
         copy=False,
     )
     pixel_out = [p.ravel() for p in pixel_out]
-    # For each pixel in the ouput array, get the pixel value in the input WCS
+    # For each pixel in the output array, get the pixel value in the input WCS
     if roundtrip_coords:
         pixel_in = pixel_to_pixel_with_roundtrip(wcs_out, wcs_in, *pixel_out[::-1])[::-1]
     else:
