@@ -50,12 +50,14 @@ def reproject_and_coadd(
             * An `~astropy.nddata.NDData` object from which the ``.data`` and
               ``.wcs`` attributes will be used as the input data.
 
-    output_projection : `~astropy.wcs.WCS` or `~astropy.io.fits.Header`
-        The output projection, which can be either a `~astropy.wcs.WCS`
-        or a `~astropy.io.fits.Header` instance.
+    output_projection : `~astropy.wcs.wcsapi.BaseLowLevelWCS` or `~astropy.wcs.wcsapi.BaseHighLevelWCS` or `~astropy.io.fits.Header`
+        The output projection, which can be either a
+        `~astropy.wcs.wcsapi.BaseLowLevelWCS`,
+        `~astropy.wcs.wcsapi.BaseHighLevelWCS`, or a `~astropy.io.fits.Header`
+        instance.
     shape_out : tuple, optional
-        If ``output_projection`` is a `~astropy.wcs.WCS` instance, the
-        shape of the output data should be specified separately.
+        If ``output_projection`` is a WCS instance, the shape of the output
+        data should be specified separately.
     input_weights : iterable
         If specified, this should be an iterable with the same length as
         ``input_data``, where each item is one of:
@@ -241,12 +243,12 @@ def reproject_and_coadd(
         arrays.append(array)
 
     # If requested, try and match the backgrounds.
-    if match_background:
+    if match_background and len(arrays) > 1:
         offset_matrix = determine_offset_matrix(arrays)
         corrections = solve_corrections_sgd(offset_matrix)
         if background_reference:
             corrections -= corrections[background_reference]
-        for array, correction in zip(arrays, corrections):
+        for array, correction in zip(arrays, corrections, strict=True):
             array.array -= correction
 
     # At this point, the images are now ready to be co-added.
@@ -274,11 +276,12 @@ def reproject_and_coadd(
         if combine_function == "mean":
             with np.errstate(invalid="ignore"):
                 output_array /= output_footprint
+                output_array[output_footprint == 0] = 0
 
     elif combine_function in ("first", "last", "min", "max"):
         for array in arrays:
             if combine_function == "first":
-                mask = output_footprint[array.view_in_original_array] == 0
+                mask = (output_footprint[array.view_in_original_array] == 0) & (array.footprint > 0)
             elif combine_function == "last":
                 mask = array.footprint > 0
             elif combine_function == "min":
