@@ -2,8 +2,6 @@ import dask.array as da
 import numpy as np
 import pytest
 from astropy.io import fits
-from astropy.nddata import NDData
-from astropy.utils.data import get_pkg_data_filename
 from astropy.wcs import WCS
 
 from reproject.conftest import set_wcs_array_shape
@@ -17,7 +15,7 @@ def test_parse_input_data(tmpdir, valid_celestial_input_data, request):
     array_ref, wcs_ref, input_value, kwargs = valid_celestial_input_data
 
     data, wcs = parse_input_data(input_value, **kwargs)
-    assert isinstance(data, (da.Array, np.ndarray))
+    assert isinstance(data, da.Array | np.ndarray)
     np.testing.assert_allclose(data, array_ref)
     assert_wcs_allclose(wcs, wcs_ref)
 
